@@ -1,5 +1,5 @@
 /* GDA common library
- * Copyright (C) 1998-2001 The Free Software Foundation
+ * Copyright (C) 1998-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -97,8 +97,10 @@ typedef struct {
 	GList *gda_params;
 } GdaProviderInfo;
 
-GList *gda_config_get_provider_list (void);
-void   gda_config_free_provider_list (GList *list);
+GList           *gda_config_get_provider_list (void);
+void             gda_config_free_provider_list (GList *list);
+GdaProviderInfo *gda_config_get_provider_by_name (const gchar *name);
+void             gda_config_free_provider_info (GdaProviderInfo *provider_info);
 
 /*
  * Data sources configuration
@@ -118,6 +120,19 @@ GdaDataSourceInfo *gda_config_copy_data_source_info (GdaDataSourceInfo *info);
 void               gda_config_free_data_source_info (GdaDataSourceInfo *info);
 void               gda_config_free_data_source_list (GList *list);
 GdaDataModel      *gda_config_get_data_source_model (void);
+void               gda_config_save_data_source (const gchar *name,
+						const gchar *provider,
+						const gchar *cnc_string,
+						const gchar *description,
+						const gchar *username);
+
+/*
+ * GDA configuration sections/keys
+ */
+#define GDA_CONFIG_SECTION_DATASOURCES       "/apps/libgda/Datasources"
+#define GDA_CONFIG_SECTION_LAST_CONNECTIONS  "/apps/libgda/LastConnections"
+
+#define GDA_CONFIG_KEY_MAX_LAST_CONNECTIONS  "/apps/libgda/MaxLastConnections"
 
 G_END_DECLS
 
