@@ -1,5 +1,5 @@
 /* GDA client library
- * Copyright (C) 1998-2001 The Free Software Foundation
+ * Copyright (C) 1998-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *      Michael Lausch <michael@lausch.at>
@@ -58,15 +58,18 @@ struct _GdaConnectionClass {
 GType          gda_connection_get_type (void);
 GdaConnection *gda_connection_new (GdaClient *client,
 				   GNOME_Database_Connection corba_cnc,
-				   const gchar *cnc_string,
+				   const gchar *dsn,
 				   const gchar *username,
 				   const gchar *password);
 gboolean       gda_connection_close (GdaConnection *cnc);
+gboolean       gda_connection_is_open (GdaConnection *cnc);
 
 GdaClient     *gda_connection_get_client (GdaConnection *cnc);
 void           gda_connection_set_client (GdaConnection *cnc, GdaClient *client);
 
-const gchar   *gda_connection_get_string (GdaConnection *cnc);
+const gchar   *gda_connection_get_dsn (GdaConnection *cnc);
+const gchar   *gda_connection_get_cnc_string (GdaConnection *cnc);
+const gchar   *gda_connection_get_provider (GdaConnection *cnc);
 const gchar   *gda_connection_get_username (GdaConnection *cnc);
 const gchar   *gda_connection_get_password (GdaConnection *cnc);
 
@@ -88,6 +91,7 @@ typedef enum {
 gboolean       gda_connection_supports (GdaConnection *cnc, GdaConnectionFeature feature);
 
 typedef enum {
+	GDA_CONNECTION_SCHEMA_INDEXES = GNOME_Database_Connection_SCHEMA_INDEXES,
 	GDA_CONNECTION_SCHEMA_PROCEDURES = GNOME_Database_Connection_SCHEMA_PROCEDURES,
 	GDA_CONNECTION_SCHEMA_TABLES = GNOME_Database_Connection_SCHEMA_TABLES,
 	GDA_CONNECTION_SCHEMA_TYPES = GNOME_Database_Connection_SCHEMA_TYPES,
