@@ -24,6 +24,7 @@
 #  define __gda_server_recordset_h__
 
 #include <libgda/gda-row.h>
+#include <libgda/gda-command.h>
 #include <libgda/gda-server-connection.h>
 #include <bonobo/bonobo-xobject.h>
 
@@ -40,12 +41,12 @@ typedef struct _GdaServerRecordsetClass   GdaServerRecordsetClass;
 typedef struct _GdaServerRecordsetPrivate GdaServerRecordsetPrivate;
 
 struct _GdaServerRecordset {
-	BonoboXObject object;
+	BonoboObject object;
 	GdaServerRecordsetPrivate *priv;
 };
 
 struct _GdaServerRecordsetClass {
-	BonoboXObjectClass parent_class;
+	BonoboObjectClass parent_class;
 	POA_GNOME_Database_Recordset__epv epv;
 };
 
@@ -64,6 +65,13 @@ void                 gda_server_recordset_set_fetch_func (GdaServerRecordset *re
 void                 gda_server_recordset_set_describe_func (GdaServerRecordset *recset,
 							     GdaServerRecordsetDescribeFunc func);
 
+const gchar         *gda_server_recordset_get_command_text (GdaServerRecordset *recset);
+void 		     gda_server_recordset_set_command_text (GdaServerRecordset *recset,
+								const gchar *cmd_text);
+GdaCommandType	     gda_server_recordset_get_command_type (GdaServerRecordset *recset);
+void 		     gda_server_recordset_set_command_type (GdaServerRecordset *recset,
+								GdaCommandType cmd_type);
+
 G_END_DECLS
 
 #endif
